use anyhow::Context;
use axum::{
    async_trait, body::BoxBody, extract::FromRequest, http::Request, response::IntoResponse,
};
use ssh_key::Certificate;

use super::ApiError;

#[derive(Debug, Clone)]
pub struct CertificateBody(pub Certificate);

// we must implement `FromRequest` (and not `FromRequestParts`) to consume the body
#[async_trait]
impl<S> FromRequest<S, BoxBody> for CertificateBody
where
    S: Send + Sync,
{
    type Rejection = ApiError;

    async fn from_request(req: Request<BoxBody>, state: &S) -> Result<Self, Self::Rejection> {
        let body = String::from_request(req, state)
            .await
            .map_err(|err| err.into_response())
            .unwrap(); //.context("failed to extract body")?;

        let cert = Certificate::from_openssh(&body)
            .with_context(|| format!("failed to parse '{}'", body))?;

        Ok(Self(cert))
    }
}
